"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SmartlingFileTranslationsApi = void 0;
const form_data_1 = __importDefault(require("form-data"));
const base_1 = require("../base");
class SmartlingFileTranslationsApi extends base_1.SmartlingBaseApi {
    constructor(smartlingApiBaseUrl, authApi, logger) {
        super(logger);
        this.authApi = authApi;
        this.entrypoint = `${smartlingApiBaseUrl}/file-translations-api/v2/accounts`;
    }
    uploadFile(accountUid, parameters) {
        return __awaiter(this, void 0, void 0, function* () {
            const formData = new form_data_1.default();
            const exported = parameters.export();
            formData.append("file", exported.file);
            formData.append("request", JSON.stringify(exported.request), {
                contentType: "application/json"
            });
            return yield this.makeRequest("post", `${this.entrypoint}/${accountUid}/files`, formData, false, SmartlingFileTranslationsApi.fixContentTypeHeaderCase(formData));
        });
    }
    translateFile(accountUid, fileUid, params) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.makeRequest("post", `${this.entrypoint}/${accountUid}/files/${fileUid}/mt`, JSON.stringify(params.export()));
        });
    }
    getTranslationProgress(accountUid, fileUid, mtUid) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.makeRequest("get", `${this.entrypoint}/${accountUid}/files/${fileUid}/mt/${mtUid}/status`);
        });
    }
    downloadTranslatedFile(accountUid, fileUid, mtUid, localeId) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.makeRequest("get", `${this.entrypoint}/${accountUid}/files/${fileUid}/mt/${mtUid}/locales/${localeId}/file`, null, true);
        });
    }
    downloadTranslatedFiles(accountUid, fileUid, mtUid) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.makeRequest("get", `${this.entrypoint}/${accountUid}/files/${fileUid}/mt/${mtUid}/locales/all/file/zip`, null, true);
        });
    }
    cancelFileTranslation(accountUid, fileUid, mtUid) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.makeRequest("post", `${this.entrypoint}/${accountUid}/files/${fileUid}/mt/${mtUid}/cancel`);
        });
    }
    detectFileLanguage(accountUid, fileUid) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.makeRequest("post", `${this.entrypoint}/${accountUid}/files/${fileUid}/language-detection`);
        });
    }
    getLanguageDetectionProgress(accountUid, fileUid, languageDetectionUid) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.makeRequest("get", `${this.entrypoint}/${accountUid}/files/${fileUid}/language-detection/${languageDetectionUid}/status`);
        });
    }
    static fixContentTypeHeaderCase(form) {
        const headers = form.getHeaders();
        headers["Content-Type"] = headers["content-type"];
        delete headers["content-type"];
        return headers;
    }
}
exports.SmartlingFileTranslationsApi = SmartlingFileTranslationsApi;
//# sourceMappingURL=index.js.map